==> haskell-mysql-0.2.1-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-64Phdasgwzj3F0JjFSpUcx
key:                  mysql-0.2.1-64Phdasgwzj3F0JjFSpUcx
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  f2a72dc58f5124b94425c73650ff9982
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1 /usr/lib/
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-64Phdasgwzj3F0JjFSpUcx
extra-libraries:      z dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-0.2.1-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-6NXOTA3v8Cw2nFsTY3KUCQ
key:                  mysql-0.2.1-6NXOTA3v8Cw2nFsTY3KUCQ
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  613dabcbae73199b3f8645c067c2ce93
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1 /usr/lib/
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-6NXOTA3v8Cw2nFsTY3KUCQ
extra-libraries:      z dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
